@@ -1,4 +1,86 @@
 package Mojolicious::Plugin::Cloudinary;
+use Mojo::Base -base;
+use File::Basename;
+use Mojo::UserAgent;
+use Mojo::Util qw(sha1_sum url_escape);
+use Scalar::Util 'weaken';
+use base qw(Cloudinary Mojolicious::Plugin);
+
+our $VERSION = 0.0402;    # just need something higher than the previous version
+
+has js_image => '/image/blank.png';
+
+sub register {
+  my ($self, $app, $config) = @_;
+
+  for my $k (keys %{$config || {}}) {
+    $self->$k($config->{$k}) if exists $config->{$k};
+  }
+
+  $self->_ua($app->ua);
+
+  $app->helper(
+    cloudinary_upload => sub {
+      my $c = shift;
+      $self->upload(@_);
+    }
+  );
+  $app->helper(
+    cloudinary_destroy => sub {
+      my $c = shift;
+      $self->destroy(@_);
+    }
+  );
+  $app->helper(
+    cloudinary_url_for => sub {
+      my ($c, $public_id, $args) = @_;
+      my $scheme = $c->req->url->scheme || '';
+
+      if (not defined $args->{secure} and $scheme eq 'https') {
+        $args->{secure} = 1;
+      }
+
+      return $self->url_for($public_id, $args);
+    }
+  );
+  $app->helper(
+    cloudinary_image => sub {
+      my ($c, $public_id, $args, $image_args) = @_;
+      my $scheme = $c->req->url->scheme || '';
+
+      if (not defined $args->{secure} and $scheme eq 'https') {
+        $args->{secure} = 1;
+      }
+
+      return $c->image($self->url_for($public_id, $args), alt => $public_id, %$image_args);
+    }
+  );
+  $app->helper(
+    cloudinary_js_image => sub {
+      my ($c, $public_id, $args) = @_;
+      my $scheme = $c->req->url->scheme || '';
+
+      if (not defined $args->{secure} and $scheme eq 'https') {
+        $args->{secure} = 1;
+      }
+
+      return $c->image(
+        $self->js_image,
+        'alt'      => $public_id,
+        'class'    => 'cloudinary-js-image',
+        'data-src' => $public_id,
+        map {
+          my $k = $Cloudinary::LONGER{$_} || $_;
+          ("data-$k" => $args->{$_})
+        } keys %$args
+      );
+    }
+  );
+}
+
+1;
+
+=encoding utf8
 
 =head1 NAME
 
@@ -11,54 +93,26 @@ your L<Mojolicious> web application. See L</HELPERS> for details.
 
 =head1 SYNOPSIS
 
-  package MyWebApp;
-  use Mojo::Base 'Mojolicious';
+  use Mojolicious::Lite;
 
-  sub startup {
-    my $self = shift;
+  plugin cloudinary => {cloud_name => $str, api_key => $str, api_secret => $str};
 
-    $self->plugin('Mojolicious::Plugin::Cloudinary', {
-      cloud_name => $str,
-      api_key => $str,
-      api_secret => $str,
-    });
-  }
+  post "/upload" => sub {
+    my $c = shift;
 
-  package MyWebApp::SomeController;
-
-  sub upload {
-    my $self = shift;
-
-    $self->render_later;
-    Mojo::IOLoop->delay(
+    $c->delay(
       sub {
-        my($delay) = @_;
-        $self->cloudinary_upload(
-          {
-            file => $self->param('upload_param'),
-          },
-          $delay->begin,
-        );
+        my ($delay) = @_;
+        $c->cloudinary_upload({file => $c->param("upload_param")}, $delay->begin);
       },
       sub {
-        my($delay, $res, $tx) = @_;
-        return $self->render(json => $res) if $res;
-        return $self->render_exception;
+        my ($delay, $res, $tx) = @_;
+        return $c->render(json => $res) if $res;
+        return $c->render_exception;
       },
     );
   }
 
-=cut
-
-use Mojo::Base -base;
-use File::Basename;
-use Mojo::UserAgent;
-use Mojo::Util qw/ sha1_sum url_escape /;
-use Scalar::Util 'weaken';
-use base qw/ Cloudinary Mojolicious::Plugin /;
-
-our $VERSION = 0.0402;    # just need something higher than the previous version
-
 =head1 ATTRIBUTES
 
 =head2 js_image
@@ -66,10 +120,6 @@ our $VERSION = 0.0402;    # just need something higher than the previous version
 This string will be used as the image src for images constructed by
 L</cloudinary_js_image>. The default is "/image/blank.png".
 
-=cut
-
-has js_image => '/image/blank.png';
-
 =head1 HELPERS
 
 =head2 cloudinary_upload
@@ -103,13 +153,8 @@ L<http://cloudinary.com/blog/cloudinary_s_jquery_library_for_embedding_and_trans
 
 Example usage:
 
-  $c->cloudinary_js_image(1234567890 => {
-    width => 115,
-    height => 115,
-    crop => 'thumb',
-    gravity => 'faces',
-    radius => '20',
-  });
+  $c->cloudinary_js_image(1234567890 =>
+      {width => 115, height => 115, crop => "thumb", gravity => "faces", radius => "20"});
 
 ...will produce:
 
@@ -131,84 +176,8 @@ Note: The "class" and "alt" attributes are fixed for now.
 
 Will register the L</HELPERS> in the L<Mojolicious> application.
 
-=cut
+=head1 SEE ALSO
 
-sub register {
-  my($self, $app, $config) = @_;
-
-  for my $k (keys %{ $config || {} }) {
-    $self->$k($config->{$k}) if exists $config->{$k};
-  }
-
-  $self->_ua($app->ua);
-
-  $app->helper(
-    cloudinary_upload => sub {
-      my $c = shift;
-      $self->upload(@_);
-    }
-  );
-  $app->helper(
-    cloudinary_destroy => sub {
-      my $c = shift;
-      $self->destroy(@_);
-    }
-  );
-  $app->helper(
-    cloudinary_url_for => sub {
-      my($c, $public_id, $args) = @_;
-      my $scheme = $c->req->url->scheme || '';
-
-      if(not defined $args->{'secure'} and $scheme eq 'https') {
-        $args->{'secure'} = 1;
-      }
-
-      return $self->url_for($public_id, $args);
-    }
-  );
-  $app->helper(
-    cloudinary_image => sub {
-      my($c, $public_id, $args, $image_args) = @_;
-      my $scheme = $c->req->url->scheme || '';
-
-      if(not defined $args->{'secure'} and $scheme eq 'https') {
-        $args->{'secure'} = 1;
-      }
-
-      return $c->image($self->url_for($public_id, $args), alt => $public_id, %$image_args);
-    }
-  );
-  $app->helper(
-    cloudinary_js_image => sub {
-      my($c, $public_id, $args) = @_;
-      my $scheme = $c->req->url->scheme || '';
-
-      if(not defined $args->{'secure'} and $scheme eq 'https') {
-        $args->{'secure'} = 1;
-      }
-
-      return $c->image(
-        $self->js_image,
-        'alt'      => $public_id,
-        'class'    => 'cloudinary-js-image',
-        'data-src' => $public_id,
-        map {
-          my $k = $Cloudinary::LONGER{$_} || $_;
-          ("data-$k" => $args->{$_})
-        } keys %$args
-      );
-    }
-  );
-}
-
-=head1 COPYRIGHT & LICENSE
-
-See L<Cloudinary>.
-
-=head1 AUTHOR
-
-Jan Henning Thorsen - jhthorsen@cpan.org
+L<Cloudinary>.
 
 =cut
-
-1;
